@@ -180,6 +180,7 @@ class CiPipelineHandlers:
 
     @staticmethod
     def update_pre_post_ci_steps(current_steps: list, new_steps: list, plugin_metadata: dict, applied_plugin_metadata: list) -> list:
+        import re
         try:
             current_steps_indices = {}
             plugin_minimal_data = {}
@@ -218,12 +219,14 @@ class CiPipelineHandlers:
                         # Update existing custom step
                         patch_result = CiPipelineHandlers.patch_custom_step(existing_step, step, index)
                         if not patch_result["success"]:
+                            print(f"patch_custom_step failed: {patch_result.get('error')}")
                             return current_steps
                         updated_steps.append(patch_result.get("desired_step"))
                     else:
                         # Add new custom step
                         add_result = CiPipelineHandlers.add_new_custom_step(step, index)
                         if not add_result["success"]:
+                            print(f"add_new_custom_step failed: {add_result.get('error')}")
                             return current_steps
                         updated_steps.append(add_result.get("desired_step"))
                     index += 1
@@ -234,22 +237,37 @@ class CiPipelineHandlers:
                     existing_step = current_steps_indices.get((task_name, plugin_name, "plugin"))
                     
                     if existing_step:
-                        patch_pre_post_ci_step_result = CiPipelineHandlers.patch_pre_post_ci_step(existing_step, step, index, plugin_minimal_data[(step["name"], step["version"])])
+                        key = (step.get("name", ""), step.get("version", ""))
+                        if key not in plugin_minimal_data:
+                            print(f"Plugin version data not found for {key}")
+                            return current_steps
+
+                        patch_pre_post_ci_step_result = CiPipelineHandlers.patch_pre_post_ci_step(existing_step, step, index, plugin_minimal_data[key])
                         if not patch_pre_post_ci_step_result["success"]:
+                            print(f"patch_pre_post_ci_step failed: {patch_pre_post_ci_step_result.get('error')}")
                             return current_steps
                         updated_steps.append(patch_pre_post_ci_step_result.get("desired_step"))
                         index += 1
                     else:
                         detailed_plugin_version_data = []
                         for plugin_data in applied_plugin_metadata:
-                            if step.get("name", "") == plugin_data.get("name"):
+
+                            step_name = step.get("name", "")
+                            pattern = re.compile(rf"^{re.escape(step_name)}(\s+[vV]\d.*)?$")
+                            plugin_name = plugin_data.get("name")
+                            if pattern.match(plugin_name):
+                                detailed_plugin_version_data = plugin_data.get("pluginVersions", {}).get("detailedPluginVersionData", [])
+                                break
+                            elif plugin_name == step_name:
                                 detailed_plugin_version_data = plugin_data.get("pluginVersions", {}).get("detailedPluginVersionData", [])
                                 break
                         if not detailed_plugin_version_data:
+                            print(f"detailed_plugin_version_data not found for plugin: {step.get('name')}")
                             return current_steps
 
                         add_plugin_result = CiPipelineHandlers.add_new_plugin(step, index, applied_plugin_metadata, detailed_plugin_version_data)
                         if not add_plugin_result["success"]:
+                            print(f"add_new_plugin failed: {add_plugin_result.get('error')}")
                             return current_steps
                         updated_steps.append(add_plugin_result.get("desired_step"))
                         index += 1
@@ -257,7 +275,7 @@ class CiPipelineHandlers:
             return updated_steps
 
         except Exception as e:
-            print("Error occurred:", str(e))
+            print("Error occurred in update_pre_post_ci_steps:", str(e))
             return current_steps
 
     @staticmethod
