@@ -670,6 +670,7 @@ class DevtronUtils:
 
     @staticmethod
     def get_plugin_details_by_name(base_url, headers, plugin_name: str) -> dict:
+        import re
         try:
             new_plugin_name = plugin_name.replace(" ", "+")
             api_url = f"{base_url.rstrip('/')}/orchestrator/plugin/global/list/v2?searchKey={new_plugin_name}&offset=0"
@@ -680,8 +681,12 @@ class DevtronUtils:
                 plugin_search_result = data.get("result", {})
                 if plugin_search_result:
                     plugin_list = plugin_search_result.get("parentPlugins", [])
+                    pattern = re.compile(rf"^{re.escape(plugin_name)}(\s+[vV]\d.*)?$")
                     for plugin in plugin_list:
-                        if plugin.get("name") == plugin_name:
+                        name = plugin.get("name", "")
+                        if pattern.match(name):
+                            return {'success': True, 'plugin': plugin}
+                        elif name == plugin_name:
                             return {'success': True, 'plugin': plugin}
                 # Plugin not found
                 return {'success': False, 'error': f'Plugin "{plugin_name}" not found in available plugins'}
